@@ -1,7 +1,8 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2013, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 1995, 2016, Oracle and/or its affiliates. All Rights Reserved.
 Copyright (c) 2012, Facebook Inc.
+Copyright (c) 2013, 2016, MariaDB Corporation
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -209,7 +210,7 @@ mtr_start_trx(
 /*======*/
 	mtr_t*	mtr,	/*!< out: mini-transaction */
 	trx_t*	trx)	/*!< in: transaction */
-	__attribute__((nonnull (1)));
+	MY_ATTRIBUTE((nonnull (1)));
 /***************************************************************//**
 Starts a mini-transaction. */
 UNIV_INLINE
@@ -220,7 +221,7 @@ mtr_start(
 {
 	mtr_start_trx(mtr, NULL);
 }
-	__attribute__((nonnull))
+	MY_ATTRIBUTE((nonnull))
 /***************************************************************//**
 Commits a mini-transaction. */
 UNIV_INTERN
@@ -228,7 +229,7 @@ void
 mtr_commit(
 /*=======*/
 	mtr_t*	mtr)	/*!< in/out: mini-transaction */
-	__attribute__((nonnull));
+	MY_ATTRIBUTE((nonnull));
 /**********************************************************//**
 Sets and returns a savepoint in mtr.
 @return	savepoint */
@@ -321,7 +322,7 @@ mtr_memo_release(
 	mtr_t*	mtr,	/*!< in/out: mini-transaction */
 	void*	object,	/*!< in: object */
 	ulint	type)	/*!< in: object type: MTR_MEMO_S_LOCK, ... */
-	__attribute__((nonnull));
+	MY_ATTRIBUTE((nonnull));
 #ifdef UNIV_DEBUG
 # ifndef UNIV_HOTBACKUP
 /**********************************************************//**
@@ -334,7 +335,7 @@ mtr_memo_contains(
 	mtr_t*		mtr,	/*!< in: mtr */
 	const void*	object,	/*!< in: object to search */
 	ulint		type)	/*!< in: type of object */
-	__attribute__((warn_unused_result, nonnull));
+	MY_ATTRIBUTE((warn_unused_result, nonnull));
 
 /**********************************************************//**
 Checks if memo contains the given page.
