@@ -1786,7 +1786,7 @@ row_upd_sec_index_entry(
 		trx_print(stderr, trx, 0);
 		fputs("\n"
 		      "InnoDB: Submit a detailed bug report"
-		      " to http://bugs.mysql.com\n", stderr);
+		      " to https://jira.mariadb.org/\n", stderr);
 		ut_ad(0);
 		break;
 	case ROW_FOUND:
